.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _hpcc_slurm.submit:

submit
======

.. automodule:: hpcc_slurm.submit
   :members:
   :undoc-members:
   :show-inheritance:
